@@ -2,31 +2,27 @@ module PostgresqlSyntax.Rendering where
 
 import PostgresqlSyntax.Prelude hiding (aExpr, try, option, many, sortBy, bit, fromList)
 import PostgresqlSyntax.Ast
-import Data.ByteString.FastBuilder
+import Text.Builder hiding (char7, intDec, int64Dec, doubleDec)
+import PostgresqlSyntax.Extras.TextBuilder
 import qualified PostgresqlSyntax.Extras.NonEmpty as NonEmpty
 import qualified Data.List.NonEmpty as NonEmpty
 import qualified Data.Text as Text
 import qualified Data.Text.Encoding as Text
-import qualified Data.ByteString.Builder as BsBuilder
-import qualified Data.ByteString.Lazy as LazyBs
 
 
 -- * Execution
 -------------------------
 
 toByteString :: Builder -> ByteString
-toByteString = toStrictByteString
+toByteString = Text.encodeUtf8 . toText
 
 toText :: Builder -> Text
-toText = Text.decodeUtf8 . toByteString
+toText = run
 
 
 -- * Helpers
 -------------------------
 
-text :: Text -> Builder
-text = stringUtf8 . Text.unpack
-
 commaNonEmpty :: (a -> Builder) -> NonEmpty a -> Builder
 commaNonEmpty = NonEmpty.intersperseFoldMap ", "
 
